
function [B] = block(p, f, varargin)

%BLOCK creates a new block defined by sets of vertices and faces
% 
% syntax:
% [B] = block(p, f)
% [B] = block(p, f, 'PropertyName', PropertyValue, ...)
%
% input:
% p - a column matrix containing the x, y, z coordinates for each vertex
% f - a cell array containing connection matrices specifying which vertices
%     in the p are connected, each row in matrix defines one face, each
%     array's cell contains faces defined by the same number of vertices
% property name/property value pairs are used to specify additional block
% properties
%
% property list:
% BlockColor     - block's color determined according to Matlab color 
%                  specification, default 'b'
% BlockEdgeColor - edges' color determined according to Matlab color 
%                  specification, used only in the 'surf' view, default 'none'
% CSysColor      - block's coordinate system color determined according to 
%                  Matlab color specification, default 'r'
% CSysLabel      - description of the block's coordinate system, 
%                  default empty string
% CSysLabelColor - color of all descriptions of the block's coordinate 
%                  system, determined according to Matlab color 
%                  specification, default 'k'
% CSysAxisLabel  - cell array, labels of the axis of the block's coordinate 
%                  system, default {'x', 'y', 'z'}
% CSysAxisLength - x, y, and z limits of the block's coordinate system,
%                  default [0 1 0 1 0 1]
% 
% output:
% B - structure representing a block
%
% examples:
%
% b = block([[1;0;0] [0;1;0] [-1;0;0] [0;-1;0] [0;0;1]],...
%           {[1 2 3 4] [1 2 5; 2 3 5; 3 4 5; 1 4 5]})
% block_plot(b)
% campos([-3,-3,1])
% creates and plots a square pyramid with default properties
%
% b = block([[1;0;0] [0;1;0] [-1;0;0] [0;-1;0] [0;0;1]],...
%           {[1 2 3 4] [1 2 5; 2 3 5; 3 4 5; 1 4 5]},...
%           'BlockColor', 'r', 'CSysColor', 'b')
% block_plot(b)
% campos([-3,-3,1])
% creates and plots a red square pyramid with blue coordinate system
%
% See also: ARC, CONE, CUBE, CUBOID, CYLINDER, POLYLINE, PRISM, PYRAMID, SPHERE, TETRAHEDRON,
%           BLOCK_MERGE, BLOCK_MOVE,
%           BLOCK_GET, BLOCK_SET, 
%           BLOCK_PLOT, BLOCK_PLOT_CSYS
%

if ( ~parIsMatrix(p,[3,4],0) ) rethrow(geterr('argValMtx1', 'p', 3)); end
% if ( ~parIsMatrix(E,0,2)     ) rethrow(geterr('argValMtx2', 'E', 2)); end
if ( ~iscell(f)              ) rethrow(geterr('argValCell', 'f')); end

lst = optlst('block');
[code, val] = checkopts(lst(:,1), varargin{:});
switch ( code )
  case 1, rethrow(geterr('prop'));
  case 2, rethrow(geterr('propName', val));
end;

if ( size(p,1) == 3 ) p=[p; ones(1,size(p,2))]; end

B = doblock(p, f, lst(:,1), getopts(lst, varargin{:}));
