
function [B] = block_delete(B, opt)

%BLOCK_DELETE deletes the block and/or associated coordinate system
% 
% syntax:
% [B] = block_delete(B)
% [B] = block_delete(B, opt)
%
% Function removes graphical representation of the block and/or block's 
% coordinate system.
%
% input:
% B   - a block to be deleted
% opt - determines deleted element, allowed values:
%       'all'   - deletes block and coordinate system
%       'block' - deletes only block
%       'csys'  - deletes only coordinate system
%       default value 'all'
%
% output:
% B - structure representing a block with removed graphical representation
%
% example:
% b = pyramid(2,1,1)
% b = block_plot(b)
% b = block_plot_csys(b)
% campos([-3,-3,1])
% pause
% b = block_delete(b)
% creates a new pyramid and plots block and associated coordinate system,
% after pressing any key graphical representation of the block and block's 
% coordinate system are removed
%
% See also: BLOCK, CONE, CUBE, CUBOID, CYLINDER, PRISM, PIRAMID, SPHERE, TETRAHEDRON,
%           BLOCK_PLOT, BLOCK_PLOT_CSYS
%

if ( nargin < 2 ) opt='all'; end

if ( ~parIsObj(B,'block') ) rethrow(geterr('argValObj', 'B', 'block')); end
if ( ~parIsVectorTxt(opt) ) rethrow(geterr('argValTxt', 'opt')); end
if ( ~strcmpi(opt,'all') & ~strcmpi(opt,'block') & ~strcmpi(opt,'csys') ) 
  rethrow(geterr('argVal','opt','all, csys, robot')); 
end

if ( strcmp(opt, 'all') | strcmp(opt, 'block') )
  delete(B.fig.handle);
  B.fig.handle = [];
end

if ( strcmp(opt, 'all') | strcmp(opt, 'csys') )
  delete(B.csys.handle);
  B.csys.handle = [];
end

if ( nargout == 0 ) clear B; end
