
function [B] = block_merge(B, varargin)

%BLOCK_MERGE combines given blocks and creates one block
% 
% syntax:
% [B] = block_merge(B1, ...)
%
% A new block is described in the coordinate system of block B1, and has all 
% properties of this block.
%
% input:
% B1,... - a list of blocks to be merged
%
% output:
% B - structure representing a new block
%
% example:
% b1 = cuboid(2,1,1)
% b2 = pyramid(2,1,1)
% b  = block_merge(b1, block_move(b2,[0;0;1]))
% creates a new block composed of cuboid and pyramid on its top
%
% See also: BLOCK, CUBE, CUBOID, CYLINDER, PRISM, PIRAMID, SPHERE, TETRAHEDRON,
%           BLOCK_MOVE, BLOCK_PLOT, BLOCK_PLOT_CSYS
%

if ( ~parIsObj(B,'block') ) rethrow(geterr('argValObj', 'B', 'block')); end

t = [B.T(1:3,1:3)' -B.T(1:3,1:3)'*B.T(1:3,4); 0 0 0 1];

for i=1:length(varargin)

  b = varargin{i};
  if ( ~parIsObj(b,'block') ) rethrow(geterr('argValObj','blocks','block')); end

  b.points = t * b.T * b.points;

  ls = length(B.faces);
  lp = size(B.points,2);

  B.points = [B.points b.points];
  % B.edges  = [B.edges; b.edges+lp];

  for j=1:length(b.faces)
    B.faces{j+ls} = b.faces{j}+lp;
  end
  
  B.fig.handle = [B.fig.handle, b.fig.handle];

  B.csys.handle = [B.csys.handle, b.csys.handle];

end
