
function [B] = block_motion(B, q, delay, trace)

%BLOCK_MOTION shows animation of the block
% 
% syntax:
% [B] = block_motion(B, q)
% [B] = block_motion(B, q, delay)
% [B] = block_motion(B, q, delay, trace)
%
% input:
% B     - a block to be animated
% q     - cell array containing 4x4 transformation matrix determining
%         position and orientation in each animation step
% delay - pause between animation steps (in seconds), default 0
% trace - determines method of motion's plotting 
%         0 - in each time instant only current motion's phase is visible
%         1 - all motion's phases are visible, 
%         default 0
%
% output:
% B - structure representing a block after animation
%
% examples:
%
% q={}; for i=1:100, q{i}=rp2t(rotx(i*0.0628),[i*0.1;i*0.1;i*0.1]); end
% axis([-1 11 -1 11 -1 11])
% b = pyramid(1,1,1)
% b = block_motion(b, q, 0.025)
% shows animation of pyramid, block is moved from position (0,0,0) to
% (10,10,10), during its motion is rotated around x-axis by 2*pi radians
%
% q={}; for i=1:50, q{i}=rp2t(rotz(i*0.0628),[i*0.1;i*0.1;i*0.1]); end
% axis([-1 6 -1 6 -1 6])
% b = pyramid(1,1,1)
% b = block_plot(b)
% b = block_plot_csys(b)
% b = block_motion(b, q, 0.025)
% shows animation of pyramid with its coordinate system, block is moved 
% from position (0,0,0) to (5,5,5), during its motion is rotated around 
% z-axis by pi radians
%
% See also: BLOCK, CONE, CUBE, CUBOID, CYLINDER, PRISM, PIRAMID, SPHERE, TETRAHEDRON,
%           BLOCK_PLOT, BLOCK_PLOT_CSYS
%

if ( nargin < 4 ) trace=0;   end
if ( nargin < 3 ) delay=0.0; end

if ( ~parIsObj(B,'block')  ) rethrow(geterr('argValObj', 'B', 'block')); end
if ( ~parIsCellT(q,0)      ) rethrow(geterr('argValCellT', 'q')); end
if ( ~parIsVector(delay,1) ) rethrow(geterr('argValNum', 'delay')); end

hold on
for i=1:length(q)
  B = blkmv(B, q{i}, 0);
  if ( ~trace ) B=block_delete(B); end
  B = blkplt(B, -1);
  drawnow; pause(delay)
end
hold off

if ( nargout == 0 ) clear B; end
