
function [B] = block_move(B, T, kind)

%BLOCK_MOVE changes position and/or orientation of a given block
% 
% syntax:
% [B] = block_move(B, T)
% [B] = block_move(B, T, kind)
%
% input:
% B - a block to be moved
% T - 4x4 transformation matrix determining position and orientation or
%     3x1 position vector 
% kind - method for determining new position and/or orientation
%        allowed values:
%        0 - T is new position and orientation, default value
%        1 - current position and orientation transformed according to
%            dependency T*Tb
%        2 - current position and orientation transformed according to
%            dependency Tb*T
%        where: 
%        Tb-current position and orientation; T-given transformation matrix
%
% output:
% B - structure representing a block in the new position and orientation
%
% example:
% b = pyramid(2,1,1)
% b = block_move(b,rp2t(rotx(pi),[0;0;-1]))
% creates a new pyramid (base lies in xy-plane, base center is located in 
% (0,0) point), rotates it around x-axis by pi radians and moves along 
% z-axis by 1 unit, finally the apex of pyramid is in (0,0,0) point
%
% See also: RP2T, ROTX, ROTY, ROTZ
%

if ( nargin < 3 ) kind=0; end
if (( size(T,1) == 3 ) & ( size(T,2) == 1 )) T=rp2t(eye(3), T); end

if ( ~parIsObj(B,'block')      ) rethrow(geterr('argValObj', 'B', 'block')); end
if ( ~parIsMatrix(T,4,4)       ) rethrow(geterr('argValT', 'T')); end
if (( kind > 2 ) | ( kind < 0 )) rethrow(geterr('argVal', '0, 1, 2')); end

B = blkmv(B, T, kind);
