
function [B] = cone(r, h, varargin)

%CONE creates a new cone with the given parameters
% 
% syntax:
% [B] = cone(r, h)
% [B] = cone(r, h, n)
% [B] = cone(..., 'PropertyName', PropertyValue, ...)
%
% Cone is approximated by regular pyramid. Block's base lies in xy-plane, 
% point (0, 0, 0) is located in the center of the base.
%
% input:
% r - the radius of the base
% h - the height of cone
% n - the number of base's edges, default 8
% property name/property value pairs are used to specify additional block
% properties, see function 'block'
%
% output:
% B - structure representing a block
%
% examples:
%
% b = cone(2, 3)
% block_plot(b)
% campos([-3,-3,1])
% creates and plots a cone approximated by regular pyramid, the base is a 
% polygon with 8 sides, the radius of base equals 2, and the height of the 
% block equals 3, all properties are default 
%
% b = cone(2, 3, 32)
% block_plot(b)
% campos([-3,-3,1])
% creates and plots a cone approximated by regular pyramid, the base is a 
% polygon with 32 sides, the radius of base equals 2, and the height of 
% the block equals 3, all properties are default 
%
% See also: BLOCK,
%           BLOCK_MERGE, BLOCK_MOVE,
%           BLOCK_GET, BLOCK_SET, 
%           BLOCK_PLOT, BLOCK_PLOT_CSYS
%

if ( ~parIsVector(r,1) ) rethrow(geterr('argValNum','r')); end
if ( ~parIsVector(h,1) ) rethrow(geterr('argValNum','h')); end

if (( length(varargin) > 0 ) & isnumeric(varargin{1}) )
  n = varargin{1};
  varargin = varargin(2:length(varargin));
else n = 8; end

p = [ [dopolygon(r, n);zeros(1,n)], [0;0;h] ];
f{1} = 1:n;
f{2} = [ [[1:n-1]';n] [[2:n]';1] ones(n,1)*(n+1) ];
B = block(p, f, varargin{:});
