
function [CS]=csys(T, varargin)

%CSYS creates a new coordinate system defined by 4x4 transformation matrix
% 
% syntax:
% [CS] = csys(T)
% [CS] = csys(T, 'PropertyName', PropertyValue, ...)
%
% input:
% T - 4x4 transformation matrix determining position and orientation
% property name/property value pairs are used to specify additional 
% properties
%
% property list:
% CSysAxisLabel  - cell array, labels of the axis of the coordinate system,
%                  default {'x', 'y', 'z'}
% CSysAxisLength - x, y, and z limits of the coordinate system,
%                  default [-1 1 -1 1 -1 1]
% CSysColor      - axis' color determined according to Matlab color 
%                  specification, default 'k'
% CSysLabel      - description of the coordinate system, 
%                  default empty string
% CSysLabelColor - color of all descriptions of the coordinate system
%                  determined according to Matlab color specification, 
%                  default 'k'
% 
% output:
% CS - structure representing a coordinate system
%
% examples:
%
% axis([-3 3 -3 3 -3 3]);
% cs = csys(rp2t(rotz(pi/4),[0;0;0]))
% cs = csys_plot(cs)
% creates and plots a coordinate system, its origin is located in (0,0,0) 
% point, system is rotated around z-axis by pi/4 radians, all properties are
% default
%
% axis([-3 3 -3 3 -3 3]);
% cs = csys(eye(4), 'CSysAxisLength', axis)
% cs = csys_plot(cs)
% creates and plots global coordinate system
%
% See also: RP2T, ROTX, ROTY, ROTZ,
%           CSYS_GET, CSYS_SET, 
%           CSYS_PLOT
%

if ( ~parIsMatrix(T,4,4) ) rethrow(geterr('argValT', 'T')); end

lst = optlst('csys');
[code, val] = checkopts(lst(:,1), varargin{:});
switch ( code )
  case 1, rethrow(geterr('prop'));
  case 2, rethrow(geterr('propName', val));
end;

CS = docsys(T, lst(:,1), getopts(lst, varargin{:}));
