
function [CS] = csys_move(CS, T, kind)

%CSYS_MOVE changes position and/or orientation of a given coordinate system
% 
% syntax:
% [CS] = csys_move(CS, T)
% [CS] = csys_move(CS, T, kind)
%
% input:
% CS - a coordinate system to be moved
% T - 4x4 transformation matrix determining position and orientation or
%     3x1 position vector 
% kind - method for determining new position and/or orientation
%        allowed values:
%        0 - T is new position and orientation, default value
%        1 - T describes changes of position and orientation according to 
%            global coordinate system (new position and orientation 
%            is caclulated using dependency T*Tcs)
%        2 - T describes changes of position and orientation according to 
%            current coordinate system (new position and orientation 
%            is caclulated using dependency Tcs*T)
%        where: 
%        Tcs-current position and orientation; T-given transformation matrix
%
% output:
% CS - structure representing a coordinate system in the new position 
%      and orientation
%
% example:
% cs = csys(eye(4))
% cs = csys_move(cs,rp2t(rotx(pi),[0;0;-1]))
% creates a new coordinate system (coinciding with the global coordinate 
% system), rotates it around x-axis by pi radians and moves along 
% z-axis by 1 unit
%
% See also: RP2T, ROTX, ROTY, ROTZ
%

if ( nargin < 3 ) kind=0; end
if (( size(T,1) == 3 ) & ( size(T,2) == 1 )) T=rp2t(eye(3), T); end

if ( ~parIsObj(CS,'csys')      ) rethrow(geterr('argValObj', 'CS', 'csys')); end
if ( ~parIsMatrix(T,4,4)       ) rethrow(geterr('argValT', 'T')); end
if (( kind > 2 ) | ( kind < 0 )) rethrow(geterr('argVal', '0, 1, 2')); end

CS = csmv(CS, T, kind);
