
function [B] = cylinder(r, h, varargin)

%CYLINDER creates a new cylinder with the given parameters
% 
% syntax:
% [B] = cylinder(r, h)
% [B] = cylinder(r, h, n)
% [B] = cylinder(..., 'PropertyName', PropertyValue, ...)
%
% Cylinder is approximated by right prism. Block's base lies in xy-plane, 
% point (0, 0, 0) is located in the center of the base.
%
% input:
% r - the radius of the base
% h - the height of cylinder
% n - the number of base's edges, default 8
% property name/property value pairs are used to specify additional block
% properties, see function 'block'
%
% output:
% B - structure representing a block
%
% examples:
%
% b = cylinder(2, 3)
% block_plot(b)
% campos([-3,-3,1])
% creates and plots a cylinder approximated by right prism, the base is a 
% polygon with 8 sides, the radius of base equals 2, and the height of the 
% block equals 3, all properties are default 
%
% b = cylinder(2, 3, 32)
% block_plot(b)
% campos([-3,-3,1])
% creates and plots a cylinder approximated by right prism, the base is a 
% polygon with 32 sides, the radius of base equals 2, and the height of the 
% block equals 3, all properties are default 
%
% See also: BLOCK, 
%           BLOCK_MERGE, BLOCK_MOVE,
%           BLOCK_GET, BLOCK_SET, 
%           BLOCK_PLOT, BLOCK_PLOT_CSYS
%

if ( ~parIsVector(r,1) ) rethrow(geterr('argValNum','r')); end
if ( ~parIsVector(h,1) ) rethrow(geterr('argValNum','h')); end

if (( length(varargin) > 0 ) & isnumeric(varargin{1}) )
  n = varargin{1};
  varargin = varargin(2:length(varargin));
else n = 8; end

p = dopolygon(r, n);
[p, f] = add3dim(p, h);
B = block(p, f, varargin{:});
