
function [R]=robot(dh, joints, varargin)

%ROBOT creates a new robot defined by DH parameters and joints' types
% 
% syntax:
% [R] = robot(dh, joints)
% [R] = robot(dh, joints, 'PropertyName', PropertyValue, ...)
%
% input:
% dh     - 4xn matrix containing DH parameters, n - number of joints
% joints - n-element character array containing joints' types, 
%          allowed values:
%          'r' - revolute joint
%          'p' - prismatic joint, type I
%          'd' - prismatic joint, type II
%          Type of prismatic joint, is important only in default 3D view,
%          model 'range' (see: robot_plot and property RobotModel). 
% property name/property value pairs are used to specify additional robot
% properties
%
% property list:
%
% RobotBase        - 4x4 transformation matrix or 3x1 vector, position and 
%                    orientation of robot's base, default eye(4)
% RobotGrasper     - 4x4 transformation matrix or 3x1 vector, position and 
%                    orientation of the grasper's coordinate system,
%                    in default views grasper is plotted along the x-axis of 
%                    its coordinate system, default eye(4)
% RobotGrasperSize - 2 elements vector or number, size of robot's grasper
%                    in xy-plane, if parameter is a vector first element 
%                    defines length along x-axis, second element length
%                    along y-axis, default [0 0]
% RobotRange       - 2 columns matrix, range of robot's joints, i-th row contains 
%                    lower and upper limits on i-th generalized coordinate,
%                    default -Inf..Inf
%
% RobotLineWidth      - width of the lines in 'line' view
% RobotCylinderRadius - radius of cylinder representing arm of robot in
%                       default 3D view (see: robot_plot), default 1
% RobotCylinderApprox - approximation of cylinder representing arm of robot
%                       in default 3D view (see: robot_plot), cylinder is 
%                       approximated by right prism, value specifies number 
%                       of base's edges, default 8
%
% RobotColor         - 4 elements cell array or single value,
%                      robot's color determined according to Matlab color 
%                      specification, used in default views; 
%                      if parameter is a cell array individual elements 
%                      correspond to properties: RobotLengthColor, 
%                      RobotOffsetColor, RobotGrasperColor, RobotExColor;
%                      if parameter is a single value defines values of 
%                      properties: RobotLengthColor, RobotOffsetColor, 
%                      RobotGrasperColor, RobotExColor;
%                      default 'b'
% RobotLengthColor   - color of objects representing arm's length, 
%                      used in default views, default 'b'
% RobotOffsetColor   - color of objects representing arm's offset, 
%                      used in default views, default 'b'
% RobotGrasperColor  - color of objects representing grasper, 
%                      used in default views, default 'b'
% RobotExColor       - color of objects representing additional elements
%                      of the arm (see: RobotModel), used in default 3D view,
%                      default 'b'
%
% RobotEdgeColor         - 4 elements cell array or single value,
%                          edges' color determined according to Matlab color 
%                          specification, used only in 'surf' view;
%                          if parameter is a cell array individual elements 
%                          correspond to properties: RobotLengthEdgeColor, 
%                          RobotOffsetEdgeColor, RobotGrasperEdgeColor, RobotExEdgeColor, 
%                          if parameter is a single value defines values of 
%                          properties:  RobotLengthEdgeColor, RobotOffsetEdgeColor, 
%                          RobotGrasperEdgeColor, RobotExEdgeColor, 
%                          default 'none'
% RobotLengthEdgeColor   - edges' color of objects representing arm's length, 
%                          used only in 'surf' views, default 'none'
% RobotOffsetEdgeColor   - edges' color of objects representing arm's offset, 
%                          used only in 'surf' views, default 'none'
% RobotGrasperEdgeColor  - edges' color of objects representing grasper, 
%                          used only in 'surf' views, default 'none'
% RobotExEdgeColor       - edges' color of objects representing additional elements
%                          of the arm (see: RobotModel), used in default 3D view,
%                          default 'none'
%
% RobotModel - string, method of plotting the robot in default 3D view,
%              allowed values: 
%              'config'   - dimensions of each arm result from the current 
%                           values (length and offset) of DH parameters,
%                           note: length of the arm in prismatic joint is variable
%              'configex' - same as 'config', but each connection between the 
%                           adjacent arms is marked out by an additional element
%              'range'    - length of the arm in revolute joint is equal to
%                           suitable DH parameter;
%                           length of the first arm in prismatic joint is
%                           calculated based on range of suitable robot's joint
%                           (see: property RobotRange), note: length of the
%                           arm in prismatic joint is constant
%              'rangeex'  - same as 'range',  but each connection between the 
%                           adjacent arms is marked out by an additional element
%              default 'config'
%
% CSysColor      - robot's coordinate system color determined according to 
%                  Matlab color specification, default 'r'
% CSysLabel      - cell array, description of the robot's coordinate systems, 
%                  default {'0', '1', '2', ... , 'E'}
% CSysLabelColor - color of all descriptions of the robots's coordinate 
%                  systems, determined according to Matlab color specification, 
%                  default 'k'
% CSysAxisLabel  - cell array, labels of the axis of the robot's coordinate 
%                  systems, default {'x', 'y', 'z'}
% CSysAxisLength - x, y, and z limits of the robot's coordinate systems,
%                  default [0 1 0 1 0 1]
% 
% output:
% R - structure representing robot
%
% examples:
%
% axis([-6 1 -1 6 -1 6]);
% r = robot([dh(0,0,0,pi/2); dh(0,5,0,pi/2); dh(0,5,0,-pi/4)], ['r','r','r']);
% r = robot_plot(r, 'line');
% r = robot_plot_csys(r);
% campos([4,-4,-3])
% creates and plots a planar manipulator with three revolute kinematics pairs 
% and coordinates systems connected to robot joints, all robot's properties
% have default values
%
% r = robot([dh(0,0,5,0); dh(pi/2,0,5,-pi/2); dh(-pi/2,2,3,0)], ['p'; 'd'; 'p'],...
%           'RobotBase', rp2t(rotx(-pi/2),[0;0;0]),...
%           'RobotGrasper', rp2t(roty(-pi/2),[0; 0; 3]),...
%           'RobotRange', [-3.5, 8.5; 1, 11; 0, 5], ...
%           'RobotModel', 'rangeex',...
%           'RobotCylinderRadius', 0.5,... 
%           'RobotCylinderApprox', 16);
% r = robot_plot(r, 'mesh');
% campos([-7,-10,15])
% creates and plots a spatiial manipulator with three prismatic joints,
% base is transformed in such a way as to ensure a natural position of the robot,
% grasper's coordinate system is transformed in such a way that the 
% grasper was an extension of the last robot's arm,
% limits on generalized coordinates of the robot has been defined,
% the robot will be plotted in default 3D view, model 'rangeex', the arms
% will be cylinders (approximated by right prism, 15 sides of base, see: cylinder) 
% with radius equals 0.5 
%
% See also: ROBOT_ARM, ROBOT_CONFIG,
%           ROBOT_GET, ROBOT_SET, 
%           ROBOT_PLOT, ROBOT_PLOT_CSYS, ROBOT_DELETE
%

if ( ~parIsMatrix(dh,0,4)               ) rethrow(geterr('argValMtx2', 'dh', 4)); end
if ( ~parIsVectorTxt(joints,size(dh,1)) ) rethrow(geterr('argValVectTxt', 'joints', size(dh,1))); end

lst = optlst('robot');
[code, val] = checkopts(lst(:,1), varargin{:});
switch ( code )
  case 1, rethrow(geterr('prop'));
  case 2, rethrow(geterr('propName', val));
end;

R = dorobot(dh, joints, lst(:,1), getopts(lst, varargin{:}));
