
function [R] = robot_arm(R, nr, varargin)

%ROBOT_ARM defines the apperance of robot's arm
% 
% syntax:
% [R] = robot_arm(R, nr, block, ...)
%
% input:
% R         - structure representing a robot
% nr        - joint number which apperance is defined
% block,... - a list of blocks defining the apperance of robot's arm
%
% output:
% R - structure representing a robot with modified apperance
%
% example:
% r = robot( [dh(0,0,0,-pi/4); dh(0,7,0,pi/2)], ['r', 'r'],...
%            'RobotBase', rp2t(rotx(-pi/2),[0;0;0]),... 
%            'RobotGrasper', [5; 0; -1]);
% b = block_move(cuboid(1, 1, 10), rp2t(roty(pi/2),[-2.5;0;0]));
% r = robot_arm(r, 1, b);
% b = block_move(cuboid(1, 1, 5), rp2t(roty(pi/2),[-0.5;0;-1]));
% r = robot_arm(r, 2, b);
% b1 = block_move(cuboid(1,1,0.25), [0;0;0.25]);
% b2 = block_move(cuboid(1,1,0.25), [0;0;-0.5]);
% r = robot_arm(r, 3, b1, b2);
% 
% axis([-5 15 -10 10 -5 10])
% robot_plot(r, 'mesh')
% campos([2,-1,1.5])
% 
% creates and plots a robot with two revolute joints, each arm is a cuboid
% with base's edges length equal 1, grasper is build from two small cuboids
%
% See also: ROBOT, ROBOT_PLOT,
%           BLOCK 
%

if ( ~parIsObj(R,'robot') ) rethrow(geterr('argValObj', 'R', 'robot')); end
if ( ~parIsVector(nr,1)   ) rethrow(geterr('argValNum', 'nr')); end
if (( nr < 0 ) | ( nr > R.n+1 )) rethrow(geterr('argVal', 'nr', sprintf('%d..%d',0,R.n+1))); end
for i=1:length(varargin)
  if ( ~parIsObj(varargin{i},'block') ) rethrow(geterr('argValObj', 'blocks', 'block')); end
end;

for i=1:size(R.user3d.blocks,2)
  R.user3d.blocks{nr+1, i} = [];
end

for i=1:length(varargin)
  R.user3d.blocks{nr+1, i} = varargin{i};
end
