
function [val] = robot_config(R, Q)

%ROBOT_CONFIG changes or returns current configuration of the robot
% 
% syntax:
% [R]    = robot_config(R, conf)
% [conf] = robot_config(R)
%
% input:
% R    - structure representing a robot
% conf - vector, new configuration of the robot
%
% output:
% R    - structure representing a robot with new configuration
% conf - current configuration of the robot
%
% example:
% r = robot([dh(0,0,0,pi/2); dh(0,5,0,pi/2); dh(0,5,0,-pi/4)], ['r','r','r']);
% r = robot_config(r, [pi/4; pi/2; -pi/2]);
% conf = robot_config(r)
% creates a planar manipulator with three revolute kinematics pairs, 
% sets its configuration to [pi/4; pi/2; -pi/2], next gets and displays 
% current configuration
%
% See also: ROBOT
%

if ( ~parIsObj(R,'robot') ) rethrow(geterr('argValObj', 'R', 'robot')); end

if ( nargin == 1 )
  val = rcfgget(R);
else
  if ( ~parIsVector(Q, R.n) ) rethrow(geterr('argValVect', 'Q', R.n)); end
  for i=1:R.n
    if ( Q(i) < R.range(i,1) ) 
      Q(i) = R.range(i,1);
      warning('ROBOT:robotRange2', getwrn('robotRange2', i, Q(i)))
    elseif ( Q(i) > R.range(i,2) ) 
      Q(i) = R.range(i,2);
      warning('ROBOT:robotRange2', getwrn('robotRange2', i, Q(i)))
    end
  end
  val = rcfgset(R, Q);
end
