
function [R] = robot_delete(R, opt)

%ROBOT_DELETE deletes the robot and/or associated coordinates systems
% 
% syntax:
% [R] = robot_delete(R)
% [R] = robot_delete(R, opt)
%
% Function removes graphical representation of the robot and/or 
% coordinates systems connected to its joints.
%
% input:
% R   - a robot to be deleted
% opt - determines deleted element, allowed values:
%       'all'   - deletes robot and coordinates systems
%       'robot' - deletes only robot
%       'csys'  - deletes only coordinates systems
%       default value 'all'
%
% output:
% R - structure representing a robot with removed graphical representation
%
% example:
% axis([-5 15 -10 10 -5 10]);
% r = robot([dh(0,0,0,-pi/4); dh(0,5,0,pi/2); dh(0,5,0,-pi/4)], ['r','r','r'], ...
%           'RobotBase', rp2t(rotx(-pi/2),[0;0;0]), 'RobotGrasper', [3; 0; 0]);
% r = robot_plot(r, 'line');
% r = robot_plot_csys(r);
% pause
% r = robot_delete(r, 'csys');
% creates and plots a planar manipulator with three revolute kinematics pairs 
% and coordinates systems connected to robot joints, after pressing any key 
% coordinates systems are removed
%
% See also: ROBOT, ROBOT_PLOT, ROBOT_PLOT_CSYS
%

if ( nargin < 2 ) opt='all'; end

if ( ~parIsObj(R,'robot') ) rethrow(geterr('argValObj', 'R', 'robot')); end
if ( ~parIsVectorTxt(opt) ) rethrow(geterr('argValTxt', 'opt')); end
if ( ~strcmpi(opt,'all') & ~strcmpi(opt,'robot') & ~strcmpi(opt,'csys') ) 
  rethrow(geterr('argVal','opt','all, csys, robot')); 
end

if ( strcmp(opt, 'all') | strcmp(opt, 'robot') )
  delete(R.fig.handle);
  R.fig.handle = [];
  if ( ~isempty(R.cblock) ) R.cblock=block_delete(R.cblock); end
end;

if ( strcmp(opt, 'all') | strcmp(opt, 'csys') )
  delete(R.csys.handle);
  R.csys.handle = [];
end;

if ( nargout == 0 ) clear R; end
