
function [R] = robot_motion(R, Q, delay, trace)

%ROBOT_MOTION shows manipulator movement according to the given trajectory
% 
% syntax:
% [R] = robot_motion(R, q)
% [R] = robot_motion(R, q, delay)
% [R] = robot_motion(R, q, delay, trace)
%
% input:
% R     - structure representing a robot
% q     - matrix with number of rows equals number of configuration variables,
%         each column corresponds to single configuration
% delay - pause between animation steps (in seconds), default 0
% trace - determines method of motion's plotting 
%         0 - in each time instant only one configuration is visible
%         1 - all configurations given by "q" are visible, 
%         default 0
%
% output:
% R - structure representing a robot at the last configuration
%
% example:
% axis([-5 5 -5 5 -3 3]);
% campos([-3 -3 1]);
% r = robot([dh(0,0,0,0)], ['r'], 'RobotGrasper', [4;0;0]);
% r = robot_plot(r);
% r = robot_plot_csys(r,1,0,1);
% r = robot_motion(r,0:pi/20:pi,0.1);
% creates a robot with one revolute joint, plots a robot with its coordinates systems,
% shows motion of the robot from configuration 0 to pi radians
%
% See also: ROBOT, ROBOT_PLOT, ROBOT_PLOT_CSYS
%

if ( nargin < 4 ) trace=0;   end
if ( nargin < 3 ) delay=0.0; end

if ( ~parIsObj(R,'robot')  ) rethrow(geterr('argValObj', 'R', 'robot')); end
if ( ~parIsMatrix(Q,R.n,0) ) rethrow(geterr('argValMtx1', 'Q', R.n)); end
if ( ~parIsVector(delay,1) ) rethrow(geterr('argValNum', 'delay')); end

hold on
for i=1:size(Q, 2)
  R = rcfgset(R, Q(:,i));
  if ( ~trace ) R=robot_delete(R); end
  R = rplt(R, -1);
  drawnow; pause(delay)
end
hold off

if ( nargout == 0 ) clear R; end
