
function [R] = robot_plot_csys(R, nr, base, grasper)

%ROBOT_PLOT_CSYS plots the robot's coordinates systems
% 
% syntax:
% [R] = robot_plot_csys(R)
% [R] = robot_plot_csys(R, nr)
% [R] = robot_plot_csys(R, nr, base)
% [R] = robot_plot_csys(R, nr, base, grasper)
%
% Parameters of the coordinate systems are defined by properties of robot,
% see function 'robot'.
%
% input:
% R       - a robot which coordinate system is to be plotted
% nr      - boolean value or vector, sets visibility indyvidual robot's
%           coordinates systems
% base    - boolean value, sets visibility of base coordinate system
% grasper - boolean value, sets visibility of grasper coordinate system
%
% output:
% R - structure representing a robot with plotted coordinate system
%
% example:
% axis([-5 15 -10 10 -5 10]);
% r = robot([dh(0,0,0,-pi/4); dh(0,5,0,pi/2); dh(0,5,0,-pi/4)], ['r','r','r'], ...
%           'RobotBase', rp2t(rotx(-pi/2),[0;0;0]), 'RobotGrasper', [3; 0; 0]);
% r = robot_plot(r, 'mesh');
% r = robot_plot_csys(r, [0 1 0], 1, 1);
% creates and plots a planar manipulator with three revolute kinematics pairs 
% in default 3D view and coordinates systems connected to second joint, base 
% and grasper
%
% See also: ROBOT, ROBOT_GET, ROBOT_SET, 
%           ROBOT_PLOT, ROBOT_DELETE
%

if ( ~parIsObj(R,'robot') ) rethrow(geterr('argValObj', 'R', 'robot')); end

if ( nargin < 4 ) grasper = 0; end
if ( nargin < 3 ) base = 0; end
if ( nargin < 2 ) nr = ones(1, R.n); end

if ( length(nr) == 1 ) nr=ones(1, R.n)*nr; end

hold on
R = rpltcsys(R, [base, nr, grasper]);
hold off

if ( nargout == 0 ) clear R; end
