
function [R] = robot_set(R, varargin)

%ROBOT_SET sets the values of the robot's properties
% 
% syntax:
% [R] = robot_set(R, 'PropertyName', PropertyValue, ...)
%
% input:
% R - structure representing a robot
% property name/property value pairs are used to specify set properties,
% see function 'robot'
%
% output:
% R - structure representing a robot with fixed properties
%
% example:
% axis([-5 15 -10 10 -5 10]);
% r = robot([dh(0,0,0,-pi/4); dh(0,5,0,pi/2); dh(0,5,0,-pi/4)], ['r','r','r'], ...
%           'RobotBase', rp2t(rotx(-pi/2),[0;0;0]), 'RobotGrasper', [3; 0; 0]);
% r = robot_set(r, 'RobotColor', 'k', 'RobotCylinderRadius', 0.5);
% r = robot_plot(r, 'mesh');
% creates a planar manipulator with three revolute kinematics pairs, 
% sets its color to 'black' and radius of cylinders (default 3D view) to 0.5,
% finally plots robot
%
% See also: ROBOT, ROBOT_GET
%

if ( ~parIsObj(R,'robot') ) rethrow(geterr('argValObj', 'R', 'robot')); end

lst = optlst('robot');
[code, val, arglst] = checkopts(lst(:,1), varargin{:});
switch ( code )
  case 1, rethrow(geterr('prop'));
  case 2, rethrow(geterr('propName', val));
end;

opt = getopts(lst, arglst{:});
for i=1:2:length(arglst) 
  R = rset(R, arglst{i}, getfield(opt,arglst{i}), 0); 
end
