
function [B] = sphere(r, varargin)

%SPHERE creates a new sphere with the given parameters
% 
% syntax:
% [B] = sphere(r)
% [B] = sphere(r, n)
% [B] = sphere(r, [n1, n2])
% [B] = sphere(..., 'PropertyName', PropertyValue, ...)
%
% Sphere is approximated by polyhedron built from trapezoids. 
% Point (0, 0, 0) is located in the center of the sphere.
%
% input:
% r  - the radius of sphere
% n  - number determining approximation of azimuthal and polar angles
% n1 - number determining approximation of an azimuthal angle, default 16
% n2 - number determining approximation of a polar angle, default 8
% property name/property value pairs are used to specify additional block
% properties, see function 'block'
%
% output:
% B - structure representing a block
%
% examples:
%
% b = sphere(3)
% block_plot(b)
% campos([-3,-3,1])
% creates and plots a sphere with radius equal 3, approximation of azimuthal 
% and polar angles are equal 16 and 8, all properties are default 
%
% b = sphere(3, 16)
% block_plot(b)
% campos([-3,-3,1])
% creates and plots a sphere with radius equal 3, approximation of azimuthal 
% and polar angles are equal 16, all properties are default 
%
% b = sphere(3, [6, 12])
% block_plot(b)
% campos([-3,-3,1])
% creates and plots a sphere with radius equal 3, approximation of azimuthal 
% and polar angles are equal 6 and 12, all properties are default 
%
% See also: BLOCK,
%           BLOCK_MERGE, BLOCK_MOVE,
%           BLOCK_GET, BLOCK_SET, 
%           BLOCK_PLOT, BLOCK_PLOT_CSYS
%

if ( ~parIsVector(r,1) ) rethrow(geterr('argValNum','r')); end

if (( length(varargin) > 0 ) & isnumeric(varargin{1}) )
  n = varargin{1};
  varargin = varargin(2:length(varargin));
  if ( length(n) == 1 ) n1 = n; n2 = n;
  else n1 = n(1); n2 = n(2); end
else n1 = 16;  n2 = 8; end


phi=linspace(0,pi,n2+1); 
theta=linspace(0,2*pi,n1+1); 
[phi,theta]=meshgrid(phi,theta); 

x = r*sin(phi).*cos(theta); 
y = r*sin(phi).*sin(theta); 
z = r*cos(phi); 

[f,v] = surf2patch(x,y,z);
v = [v'; ones(1, size(v,1))];
% e = [f(:,1) f(:,2); f(:,2) f(:,3); f(:,3) f(:,4); f(:,4) f(:,1)]; 

B = block(v, {f}, varargin{:});
