
function [Q, V, A, T, c] = trj_line(T, Q0, Qt, A0, At, V0, Vt)

%TRAJECTORY generates the robot's trajectory described by linear segment
%           with parabolic blends from initial configuration Q0 to final 
%           configuration Qt
% 
% Trajectory of each joint is described by dependencies
%
%        for t0<=t<t1:  a2*t^2 + a1*t + a0
% Q(t) = for t1<=t<t2:  b1*t + b0
%        for t2<=t<tt:  c2*t^2 + c1*t + c0
%
% syntax:
% [Q, V, A, T, c] = trj_line(T, Q0, Qt, A0, At)
% [Q, V, A, T, c] = trj_line(T, Q0, Qt, A0, At, V0, Vt)
%
% input:
% T      - number or vector, if T is a number function calculates
%          trajectory from 0 to T, if T is a vector trajectory is 
%          calculated for each time instant from T
% Q0, Qt - vector, initial and final configuration of robot
% A0, At - number or vector, initial and final acceleration, number means
%          the same value for all joints
% V0, Vt - number or vector, initial and final velocity, number means
%          the same value for all joints, default 0
%
% output:
% Q - row matrix, i-th row containts a trajectory for i-th joint
% V - row matrix, i-th row containts the instantaneous velocities of i-th joint
% A - row matrix, i-th row containts the instantaneous accelerations of i-th joint
% T - row vector of time points
% c - column matrix, i-th column containts polynomials' coefficients
%     describing trajectory for i-th joint, in some cases containts also
%     additional parameters
%
% example:
% [q, v, a, t] = trj_line(5:0.025:10, [0; 2], [3; -1], 1, 1);
% figure(1); plot(t,q(1,:), t,v(1,:), t,a(1,:))
% figure(2); plot(t,q(2,:), t,v(2,:), t,a(2,:))
% generates linear segment with parabolic blends trajectory for manipulator 
% with two joints, manipulator starts from the configuration Q0=[0;2] and 
% ends in the configuration Qt=[3;-1], the accelerations for parabolic
% segments equals 1, the start and final velocities are default(0); 
% calculated trajectory, velocities and accelerations for each joint are 
% plotted in separate figure
%
% See also: TRAJECTORY, TRJ_POLY3, TRJ_POLY5
%

if ( length(T) == 1 ) 
  T0=0; Tt=T; T=(T0:0.1:Tt);
else
  T0=T(1); Tt=T(length(T));
  if ( size(T,2) == 1 ) T=T'; end
end

if ( ~parIsMatrix(Q0,0,1) )     rethrow(geterr('argValCVect', 'Q0')); end
if ( ~parIsMatrix(Qt,0,1) )     rethrow(geterr('argValCVect', 'Qt')); end
if ( length(Q0) ~= length(Qt) ) rethrow(geterr('trjQLen')); end

n = length(Q0);

if ( nargin < 7 ) Vt=zeros(n,1); end
if ( nargin < 6 ) V0=zeros(n,1); end
if ( length(V0) == 1 ) V0=V0*ones(n,1); end
if ( length(Vt) == 1 ) Vt=Vt*ones(n,1); end
if (( length(V0) ~= n ) | ( length(Vt) ~= n )) rethrow(geterr('trjVLen')); end

if ( nargin < 5 ) rethrow(geterr('trjAUndef')); end
if ( nargin < 4 ) rethrow(geterr('trjAUndef')); end
if ( length(A0) == 1 ) A0=A0*ones(n,1); end
if ( length(At) == 1 ) At=At*ones(n,1); end
if (( length(A0) ~= n ) | ( length(At) ~= n )) rethrow(geterr('trjVLen')); end
if ( any(A0==0) | any(At==0) ) rethrow(geterr('trjAZero')); end

c = trjline(T0,Tt,Q0,Qt,V0,Vt,A0,At);
    
Q = zeros(n,length(T));  
V = zeros(n,length(T));
A = zeros(n,length(T));
for i=1:n
  disp(sprintf('\n%2d. polaczenie:\n---------------\n', i));
  if ( all(c(:,i)==0) )
    warning('ROBOT:trjLineA', getwrn('trjLineA'));
  else
    disp(sprintf('        %.2f<=t<%.2f:  %.2ft^2 + %.2ft + %.2f', T(1), c(9,i), c(1,i), c(2,i), c(3,i)));
    disp(sprintf(' Q(t) = %.2f<=t<%.2f:  %.2ft + %.2f', c(9,i), c(10,i), c(4,i), c(5,i)));
    disp(sprintf('        %.2f<=t<%.2f:  %.2ft^2 + %.2ft + %.2f\n', c(10,i), T(length(T)), c(6,i), c(7,i), c(8,i)));
    T1 = T(1:find(T<=c(9,i),1,'last'));
    T2 = T(length(T1)+1:find(T<=c(10,i),1,'last'));
    T3 = T(length(T1)+length(T2)+1:length(T));
    Q(i,:) = [polyval(c(1:3,i),T1) polyval(c(4:5,i),T2) polyval(c(6:8,i),T3)];
    V(i,:) = [polyval([2;1].*c(1:2,i),T1) c(4,i)*ones(1,length(T2)) polyval([2;1].*c(6:7,i),T3)];
    A(i,:) = [2*c(1,i)*ones(1,length(T1)) zeros(1,length(T2)) 2*c(6,i)*ones(1,length(T3))];
  end
end
