
function [Q, V, A, T, c] = trj_poly5(T, Q0, Qt, A0, At, V0, Vt)

%TRJ_POLY5 generates the robot's trajectory described by 5th order polynomial
%          from initial configuration Q0 to final configuration Qt
% 
% Trajectory of each joint is described by dependency
%
% Q(t) = a5*t^5 + a4*t^4 + a3*t^3 + a2*t^2 + a1*t + a0
%
% syntax:
% [Q, V, A, T, c] = trj_poly5(T, Q0, Qt)
% [Q, V, A, T, c] = trj_poly5(T, Q0, Qt, A0, At)
% [Q, V, A, T, c] = trj_poly5(T, Q0, Qt, A0, At, V0, Vt)
%
% input:
% T      - number or vector, if T is a number function calculates
%          trajectory from 0 to T, if T is a vector trajectory is 
%          calculated for each time instant from T
% Q0, Qt - vector, initial and final configuration of robot
% A0, At - number or vector, initial and final acceleration, number means
%          the same value for all joints, default 0
% V0, Vt - number or vector, initial and final velocity, number means
%          the same value for all joints, default 0
%
% output:
% Q - row matrix, i-th row containts a trajectory for i-th joint
% V - row matrix, i-th row containts the instantaneous velocities of i-th joint
% A - row matrix, i-th row containts the instantaneous accelerations of i-th joint
% T - row vector of time points
% c - column matrix, i-th column containts polynomials' coefficients
%     describing trajectory for i-th joint, c=[a5; a4; a3; a2; a1; a0]
%
% example:
% [q, v, a, t] = trj_poly5(5:0.025:10, [0; 2], [3; -1], 1, 1);
% figure(1); plot(t,q(1,:), t,v(1,:), t,a(1,:))
% figure(2); plot(t,q(2,:), t,v(2,:), t,a(2,:))
% generates polynomials trajectory for manipulator with two joints, 
% manipulator starts from the configuration Q0=[0;2] and ends in the 
% configuration Qt=[3;-1], the start and final accelerations equals 1,
% velocities are default (0), calculated trajectory, velocities and 
% accelerations for each joint are plotted in separate figure
%
% See also: TRAJECTORY, TRJ_POLY3, TRJ_LINE
%

if ( length(T) == 1 ) 
  T0=0; Tt=T; T=(T0:0.1:Tt);
else
  T0=T(1); Tt=T(length(T));
  if ( size(T,2) == 1 ) T=T'; end
end

if ( ~parIsMatrix(Q0,0,1) )     rethrow(geterr('argValCVect', 'Q0')); end
if ( ~parIsMatrix(Qt,0,1) )     rethrow(geterr('argValCVect', 'Qt')); end
if ( length(Q0) ~= length(Qt) ) rethrow(geterr('trjQLen')); end

n = length(Q0);

if ( nargin < 7 ) Vt=zeros(n,1); end
if ( nargin < 6 ) V0=zeros(n,1); end
if ( length(V0) == 1 ) V0=V0*ones(n,1); end
if ( length(Vt) == 1 ) Vt=Vt*ones(n,1); end
if (( length(V0) ~= n ) | ( length(Vt) ~= n )) rethrow(geterr('trjVLen')); end

if ( nargin < 5 ) At=zeros(n,1); end
if ( nargin < 4 ) A0=zeros(n,1); end
if ( length(A0) == 1 ) A0=A0*ones(n,1); end
if ( length(At) == 1 ) At=At*ones(n,1); end
if (( length(A0) ~= n ) | ( length(At) ~= n )) rethrow(geterr('trjVLen')); end
  
c = trjpoly5(T0,Tt,Q0,Qt,V0,Vt,A0,At);
    
Q = zeros(n, length(T));
V = zeros(n, length(T));
A = zeros(n, length(T));
for i=1:n
  disp(sprintf('\n%2d. polaczenie:\n---------------\n', i));
  disp(sprintf(' a5=%.5f, a4=%.5f, a3=%.5f, a2=%.5f, a1=%.5f, a0=%.5f\n', c(1,i), c(2,i), c(3,i), c(4,i), c(5,i), c(6,i)));
  disp(sprintf(' Q(t) = %.2ft^5 + %.2ft^4 + %.2ft^3 + %.2ft^2 + %.2ft + %.2f\n', c(1,i), c(2,i), c(3,i), c(4,i), c(5,i), c(6,i)));
  Q(i,:) = polyval(c(:,i),T);
  V(i,:) = polyval([5;4;3;2;1].*c(1:5,i),T);
  A(i,:) = polyval([20;12;6;2].*c(1:4,i),T);
end
